==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Web/Gui/Resources/translations/Web_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Предыдущая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Вернуться на предыдущую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Следующая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Перейти на следующую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Обновить веб-страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Остановить загрузку</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Остановить текущую загрузку</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Увеличить</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Увеличить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Уменьшить</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Уменьшить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Сеть</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Открыть сайт...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Открывает веб-сайт в FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Sketchfab экспортер</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Что загружать?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Выделение</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Все видимые объекты</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Название модели</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Частный</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Описание</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Теги (разделённые запятыми)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Формат</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (Arch exporter)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (стандартный экспортер полигональной сетки)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (только формы)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Маркер Sketchfab API</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Получить</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation>Загрузить</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>загрузка</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Успех! Просмотр загруженных онлайн</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="412"/>
      <source>Browser</source>
      <translation>Браузер</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="309"/>
      <source>File does not exist!</source>
      <translation>Файл не существует!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="304"/>
      <source>Error</source>
      <translation>Ошибки</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="383"/>
      <source>Loading %1...</source>
      <translation>Загрузка %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="181"/>
      <source>Open in External Browser</source>
      <translation>Открыть во внешнем браузере</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in new window</source>
      <translation>Открыть в новом окне</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Навигация</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Web/Gui/Resources/translations/Web_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Предыдущая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Вернуться на предыдущую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Следующая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Перейти на следующую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Обновить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Остановить загрузку</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Остановить текущую загрузку</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Увеличить</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Увеличить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Уменьшить</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Уменьшить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Открыть сайт...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Открывает сайт в FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Sketchfab экспортер</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Что загружать?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Выделение</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Все видимые объекты</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Название модели</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Приватный</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Описание</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Теги (разделённые запятыми)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Формат</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (Arch экспортер)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (стандартный экспортер полигональной сетки)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (только формы фигур)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Ключ(токен) к API Sketchfab</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Получить</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation>Загрузить</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>загрузка</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Успех! Вид выложен в онлайн</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="440"/>
      <source>Browser</source>
      <translation>Браузер</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="337"/>
      <source>File does not exist!</source>
      <translation>Файл не существует!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="329"/>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>Error</source>
      <translation>Ошибки</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Произошли ошибки при загрузке файла. Возможно, некоторые данные были изменены или не восстановлены. Посмотрите в окно отчета для более конкретной информации о затронутых объектах.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>Loading %1...</source>
      <translation>Загрузка %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in External Browser</source>
      <translation>Открыть во внешнем браузере</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="189"/>
      <source>Open in new window</source>
      <translation>Открыть в новом окне</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Навигация</translation>
    </message>
  </context>
</TS>
